@@ -5,13 +5,14 @@
 use strict;
 
 use Data::Dumper;
-use Inline Config =>
-  force_build => 1,
-  print_info => 1;
+use Inline Config => force_build => 1,
+  print_info      => 1;
 use Graphics::Framebuffer;
 $Data::Dumper::Sortkeys = 1;
 my $dev = 0;
 $dev = $ARGV[0] if (scalar(@ARGV));
+print "Using /dev/fb$dev\n";
+sleep 1;
 my $fb = Graphics::Framebuffer->new('SHOW_ERRORS' => 1, 'FB_DEVICE' => "/dev/fb$dev");
 $fb->cls();
 
@@ -21,10 +22,10 @@ delete($copy->{'SCREEN'});
 
 foreach my $name (sort(keys %{$copy})) {
     unless (ref($copy->{$name}) =~ /Imager|threads|GLOB|ARRAY|HASH|SUB/i) {
-        print STDERR "$name = ". $copy->{$name} . "\n";
+        print STDERR "$name = " . $copy->{$name} . "\n";
     }
 }
-print STDERR '='x79 . "\n";
+print STDERR '=' x 79 . "\n";
 print STDERR Dumper($copy);
 
 =head1 NAME
