@@ -22,7 +22,7 @@ my $new_y;
 our $F;
 our $FR;
 my $DIRTY = 1;
-my $dev = 0;
+my $dev   = 0;
 my $psize = 1;
 
 if ($arg =~ /X(\d+)/) {
@@ -46,10 +46,10 @@ closedir($DIR);
 our @IMAGES;
 our @SMALL_IMAGES;
 our $DB = 0;
-our $STAMP = sprintf('%.1',time);
+our $STAMP = sprintf('%.1', time);
 
 if (defined($new_x)) {
-    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y,'SPLASH' => 0);
+    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
 } else {
     $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SPLASH' => 0);
 }
@@ -57,6 +57,7 @@ if (defined($new_x)) {
 $FR->cls('OFF');
 
 my $sinfo = $FR->screen_dimensions;
+
 # If 16 bit mode and acceleration is supported, then do double-buffering
 if ($sinfo->{'bits_per_pixel'} == 16 && $FR->{'ACCELERATED'}) {
     $F = Graphics::Framebuffer->new('FB_DEVICE' => 'virtual', 'SHOW_ERRORS' => 1, 'SPLASH' => 0, 'VXRES' => $sinfo->{'width'}, 'VYRES' => $sinfo->{'height'}, 'COLOR_ORDER' => $sinfo->{'color_order'});
@@ -86,9 +87,9 @@ if ($rpi) {
     print "Putting tennis balls on the walker, because this is a Raspberry PI\n";
     sleep 3;
 }
-my $ALARM = ($rpi) ? 1/7.5 : 1/30; # Set double buffering flip timeout.  Raspberry PI has less FPS
+my $ALARM = ($rpi) ? 1 / 7.5 : 1 / 30;    # Set double buffering flip timeout.  Raspberry PI has less FPS
 my $thread;
-if ($DB) { # If double buffering is on, then enable the flip alarm
+if ($DB) {                                # If double buffering is on, then enable the flip alarm
     $SIG{'ALRM'} = sub {
         alarm(0);
         if ($DIRTY) {
@@ -98,14 +99,14 @@ if ($DB) { # If double buffering is on, then enable the flip alarm
         alarm($ALARM);
     };
     alarm($ALARM);
-}
-print_it($F, ' ','00FFFFFF');
+} ## end if ($DB)
+print_it($F, ' ', '00FFFFFF');
 $F->splash($VERSION);
-my $LOGO = $F->blit_read(); # Get a memory copy of the splash screen
+my $LOGO = $F->blit_read();    # Get a memory copy of the splash screen
 
 foreach my $file (@files) {
     next if ($file =~ /^\.+/ || $file =~ /Test|gif/ || -d "$images_path/$file");
-    print_it($F, "Loading Images > $file",'00FFFFFF',undef,1);
+    print_it($F, "Loading Images > $file", '00FFFFFF', undef, 1);
     my $image = $F->load_image(
         {
             'x'            => 1,
@@ -136,10 +137,10 @@ foreach my $file (@files) {
 $F->wait_for_console(!$rpi);
 $F->cls('OFF');
 
-$DIRTY = 1; # Set this to signal the buffer needs flipping
+$DIRTY = 1;    # Set this to signal the buffer needs flipping
 sleep 4;
 
-# if (0) { # This line only ued for debugging
+# if (0) { # This line only used for debugging
 color_mapping();
 plotting();
 foreach my $flag (0 .. 1) {
@@ -176,7 +177,7 @@ foreach my $d (qw(vertical horizontal)) {
     gradient_ellipses($d);
     gradient_pies($d);
     gradient_polygons($d);
-}
+} ## end foreach my $d (qw(vertical horizontal))
 
 texture_filled_boxes();
 texture_filled_rounded_boxes();
@@ -199,7 +200,7 @@ blit_move();
 rotate();
 flipping();
 monochrome();
-foreach my $m (1 .. 9) { # We skip divide mode because it's stupid and I should never have added it
+foreach my $m (1 .. 9) {    # We skip divide mode because it's stupid and I should never have added it
     if ($m == MASK_MODE) {
         mask_drawing();
     } elsif ($m == UNMASK_MODE) {
@@ -209,7 +210,7 @@ foreach my $m (1 .. 9) { # We skip divide mode because it's stupid and I should
     } else {
         mode_drawing($m);
     }
-}
+} ## end foreach my $m (1 .. 9)
 animated();
 
 $F->clip_reset();
@@ -218,7 +219,7 @@ $F->cls('ON');
 exec('reset');
 
 sub color_mapping {
-    
+
     print_it($F, 'Color Mapping Test -> Red-Green-Blue');
     $F->rbox(
         {
@@ -237,10 +238,10 @@ sub color_mapping {
             }
         }
     );
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor / 2;
-    
+
     $F->rbox(
         {
             'filled'   => 1,
@@ -258,10 +259,10 @@ $DIRTY = 1;
             }
         }
     );
-    
-$DIRTY = 1;
+
+    $DIRTY = 1;
     sleep $factor / 2 unless ($rpi);
-    
+
     my $image = $F->load_image(
         {
             'x'      => 0,
@@ -273,13 +274,13 @@ $DIRTY = 1;
         }
     );
     $F->blit_write($image);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor;
 } ## end sub color_mapping
 
 sub plotting {
-    
+
     print_it($F, 'Plotting Test');
 
     my $s = time + $factor;
@@ -288,14 +289,14 @@ sub plotting {
         my $y = int(rand($screen_height));
         $F->set_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->plot({ 'x' => $x, 'y' => $y, 'pixel_size' => $psize });
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub plotting
 
 sub lines {
     my $aa = shift;
-    
+
     if ($aa) {
         print_it($F, 'Antialiased Line Test');
     } else {
@@ -305,14 +306,14 @@ sub lines {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->line({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'antialiased' => $aa, 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub lines
 
 sub angle_lines {
     my $aa = shift;
-    
+
     if ($aa) {
         print_it($F, 'Antialiased Angle Line Test');
     } else {
@@ -324,36 +325,36 @@ sub angle_lines {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => int($F->{'H_CLIP'} / 2), 'angle' => $angle, 'antialiased' => $aa, 'pixel_size' => $psize });
-	    $angle += 7;
+        $angle += 7;
         $angle -= 360 if ($angle >= 360);
-$DIRTY = 1;
+        $DIRTY = 1;
     } ## end while (time < $s)
 } ## end sub angle_lines
 
 sub boxes {
-    
+
     print_it($F, 'Box Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub boxes
 
 sub filled_boxes {
-    
+
     print_it($F, 'Filled Box Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'filled' => 1 });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub filled_boxes
 
 sub gradient_boxes {
@@ -382,7 +383,7 @@ sub gradient_boxes {
                 'filled'   => 1,
                 'gradient' => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -390,13 +391,13 @@ sub gradient_boxes {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_boxes
+} ## end sub gradient_boxes
 
 sub hatch_filled_boxes {
-    
+
     print_it($F, 'Hatch Filled Box Test');
     my $s = time + $factor;
     while (time < $s) {
@@ -420,14 +421,14 @@ sub hatch_filled_boxes {
                 'hatch'  => $HATCHES[int(rand(scalar(@HATCHES)))]
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_boxes
 
 sub texture_filled_boxes {
-    
+
     print_it($F, 'Texture Filled Box Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -443,39 +444,39 @@ sub texture_filled_boxes {
                 'texture' => $image
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_boxes
 
 sub rounded_boxes {
-    
+
     print_it($F, 'Rounded Box Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub rounded_boxes
 
 sub filled_rounded_boxes {
-    
+
     print_it($F, 'Filled Rounded Box Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1 });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub filled_rounded_boxes
 
 sub hatch_filled_rounded_boxes {
-    
+
     print_it($F, 'Hatch Filled Rounded Box Test');
 
     my $s = time + $factor;
@@ -483,9 +484,9 @@ sub hatch_filled_rounded_boxes {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_rounded_boxes
 
@@ -518,7 +519,7 @@ sub gradient_rounded_boxes {
                 'filled'   => 1,
                 'gradient' => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -526,13 +527,13 @@ sub gradient_rounded_boxes {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_rounded_boxes
+} ## end sub gradient_rounded_boxes
 
 sub texture_filled_rounded_boxes {
-    
+
     print_it($F, 'Texture Filled Rounded Box Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -549,39 +550,39 @@ sub texture_filled_rounded_boxes {
                 'texture' => $image
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_rounded_boxes
 
 sub circles {
-    
+
     print_it($F, 'Circle Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub circles
 
 sub filled_circles {
-    
+
     print_it($F, 'Filled Circle Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1 });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub filled_circles
 
 sub hatch_filled_circles {
-    
+
     print_it($F, 'Hatch Filled Circle Test');
 
     my $s = time + $factor;
@@ -589,9 +590,9 @@ sub hatch_filled_circles {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_circles
 
@@ -618,7 +619,7 @@ sub gradient_circles {
                 'filled'   => 1,
                 'gradient' => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -626,13 +627,13 @@ sub gradient_circles {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_circles
+} ## end sub gradient_circles
 
 sub texture_filled_circles {
-    
+
     print_it($F, 'Texture Filled Circle Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -647,51 +648,51 @@ sub texture_filled_circles {
                 'texture' => $image
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_circles
 
 sub arcs {
-    
+
     print_it($F, 'Arc Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub arcs
 
 sub poly_arcs {
-    
+
     print_it($F, 'Poly Arc Test');
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->poly_arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub poly_arcs
 
 sub filled_pies {
-    
+
     print_it($F, 'Filled Pie Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub filled_pies
 
 sub hatch_filled_pies {
-    
+
     print_it($F, 'Hatch Filled Pie Test');
 
     my $s = time + ($factor * 2);
@@ -699,9 +700,9 @@ sub hatch_filled_pies {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_pies
 
@@ -727,7 +728,7 @@ sub gradient_pies {
                 'end_degrees'   => rand(360),
                 'gradient'      => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -735,13 +736,13 @@ sub gradient_pies {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_pies
+} ## end sub gradient_pies
 
 sub texture_filled_pies {
-    
+
     print_it($F, 'Texture Filled Pie Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -761,39 +762,39 @@ sub texture_filled_pies {
                 'texture'       => $image,
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_pies
 
 sub ellipses {
-    
+
     print_it($F, 'Ellipse Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'pixel_size' => $psize });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub ellipses
 
 sub filled_ellipses {
-    
+
     print_it($F, 'Filled Ellipse Test');
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)), 'alpha' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1 });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub filled_ellipses
 
 sub hatch_filled_ellipses {
-    
+
     print_it($F, 'Hatch Filled Ellipse Test');
 
     my $s = time + $factor;
@@ -801,9 +802,9 @@ sub hatch_filled_ellipses {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_ellipses
 
@@ -828,7 +829,7 @@ sub gradient_ellipses {
                 'filled'   => 1,
                 'gradient' => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -836,13 +837,13 @@ sub gradient_ellipses {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_ellipses
+} ## end sub gradient_ellipses
 
 sub texture_filled_ellipses {
-    
+
     print_it($F, 'Texture Filled Ellipse Test');
 
     my $s = time + $factor;
@@ -858,13 +859,13 @@ sub texture_filled_ellipses {
                 'texture' => $image
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_ellipses
 
 sub polygons {
-    
+
     my $aa = shift;
     if ($aa) {
         print_it($F, 'Antialiased Polygon Test');
@@ -887,13 +888,13 @@ sub polygons {
                 'pixel_size'  => $psize
             }
         );
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub polygons
 
 sub filled_polygons {
-    
+
     print_it($F, 'Filled Polygon Test');
     $F->mask_mode() if ($F->{'ACCELERATED'});
     my $s = time + $factor;
@@ -910,13 +911,13 @@ sub filled_polygons {
                 'filled'      => 1,
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub filled_polygons
 
 sub hatch_filled_polygons {
-    
+
     print_it($F, 'Hatch Filled Polygon Test');
     $F->mask_mode() if ($F->{'ACCELERATED'});
 
@@ -936,8 +937,8 @@ sub hatch_filled_polygons {
                 'hatch'       => $HATCHES[int(rand(scalar(@HATCHES)))]
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_polygons
@@ -964,7 +965,7 @@ sub gradient_polygons {
                 'filled'      => 1,
                 'gradient'    => {
                     'direction' => $direction,
-                    'colors' => {
+                    'colors'    => {
                         'red'   => \@red,
                         'green' => \@green,
                         'blue'  => \@blue,
@@ -972,13 +973,13 @@ sub gradient_polygons {
                 }
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
-} ## end sub vertical_gradient_polygons
+} ## end sub gradient_polygons
 
 sub texture_filled_polygons {
-    
+
     print_it($F, 'Texture Filled Polygon Test');
     $F->mask_mode() if ($F->{'ACCELERATED'});
 
@@ -997,8 +998,8 @@ sub texture_filled_polygons {
                 'texture'     => $image
             }
         );
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub texture_filled_polygons
 
@@ -1013,13 +1014,13 @@ sub beziers {
             push(@coords, int(rand($XX)), int(rand($YY)));
         }
         $F->bezier({ 'coordinates' => \@coords, 'points' => 100, 'pixel_size' => $psize });
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub beziers
 
 sub truetype_fonts {
-    
+
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
     my @fonts = (keys %{ $F->{'FONTS'} });
@@ -1049,13 +1050,13 @@ sub truetype_fonts {
             $b->{'x'} = rand($F->{'XX_CLIP'} - $b->{'pwidth'});
             $F->ttf_print($b);
         }
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $g)
 } ## end sub truetype_fonts
 
 sub rotate_truetype_fonts {
-    
+
     print_it($F, 'Testing TrueType Font Rotation Rendering');
 
     my $g     = time + $factor * 3;
@@ -1086,13 +1087,13 @@ sub rotate_truetype_fonts {
         }
         $angle++;
         $angle = 0 if ($angle >= 360);
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $g)
 } ## end sub rotate_truetype_fonts
 
 sub flood_fill {
-    
+
     print_it($F, 'Testing flood fill');
     $F->clip_reset();
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1106,8 +1107,8 @@ sub flood_fill {
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm });
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
         sleep 1 if ($F->{'ACCELERATED'});
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
 
@@ -1116,26 +1117,24 @@ $DIRTY = 1;
         $F->{'ACCELERATED'} = 0;
         $F->fill({ 'x' => int(350 * $xm), 'y' => int(250 * $ym), 'texture' => $image });
         $F->{'ACCELERATED'} = $saved;
-$DIRTY = 1;
-        
+        $DIRTY = 1;
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 960 * $xm, 'y' => 440 * $ym });
     } else {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->polygon({ 'coordinates' => [$center_x, 3, 3, $YY - 3, $center_x, $center_y, $XX - 3, $YY - 4] });
-        
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 3, 'y' => 3 });
-    } ## end else [ if ($XX > 255) ]
-$DIRTY = 1;
-    
+    } ## end else [ if ($XX > 255 && !$rpi)]
+    $DIRTY = 1;
+
     sleep $factor if ($F->{'ACCELERATED'});
 } ## end sub flood_fill
 
 sub color_replace_with_clipping {
-    
+
     print_it($F, 'Testing Color Replace (clipping on)');
 
     my $x = $F->{'XRES'} / 4;
@@ -1165,13 +1164,13 @@ sub color_replace_with_clipping {
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub color_replace_with_clipping
 
 sub color_replace_no_clipping {
-    
+
     print_it($F, 'Testing Color Replace (clipping off)');
 
     $F->blit_write($LOGO);
@@ -1201,13 +1200,13 @@ sub color_replace_no_clipping {
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
-$DIRTY = 1;
-        
+        $DIRTY = 1;
+
     } ## end while (time < $s)
 } ## end sub color_replace_no_clipping
 
 sub blitting {
-    
+
     print_it($F, 'Testing Image blitting');
 
     my $s = time + $factor;
@@ -1217,40 +1216,40 @@ sub blitting {
         $image->{'x'} = abs(rand($XX - $image->{'width'}));
         $image->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $image->{'height'}));
         $F->blit_write($image);
-$DIRTY = 1;
-        
-    }
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub blitting
 
 sub blit_move {
-    
+
     print_it($F, 'Testing Image blitting');
 
     my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
-    $F->blit_write({%{$image},'x' => 0, 'y' => 0});
+    $F->blit_write({ %{$image}, 'x' => 0, 'y' => 0 });
     my $x = 0;
     my $y = 0;
     my $w = $image->{'width'};
     my $h = $image->{'height'};
     my $s = time + $factor;
     while (time < $s) {
-        $F->blit_move({'x' => abs($x),'y' => abs($y),'width' => $w, 'height' => $h, 'x_dest' => abs($x) + 4,'y_dest' => abs($y) + 2});
+        $F->blit_move({ 'x' => abs($x), 'y' => abs($y), 'width' => $w, 'height' => $h, 'x_dest' => abs($x) + 4, 'y_dest' => abs($y) + 2 });
         $x += 4;
         $y += 2;
-        sleep (1/60);
-$DIRTY = 1;
-        
-    }
+        sleep(1 / 60);
+        $DIRTY = 1;
+
+    } ## end while (time < $s)
 } ## end sub blit_move
 
 sub rotate {
-    
+
     print_it($F, 'Scaling image for Rotate Test', 'FFFF00FF');
 
     my $image = { %{ $SMALL_IMAGES[int(rand(scalar(@IMAGES)))] } };
 
     foreach my $p (0 .. 1) {
-        
+
         my $angle = 0;
 
         my $st = 'Counter-Clockwise Rotate Test ';
@@ -1268,7 +1267,7 @@ sub rotate {
                 {
                     'rotate' => {
                         'degrees' => $angle,
-                        'quality'   => ($p) ? 'high' : 'quick',
+                        'quality' => ($p) ? 'high' : 'quick',
                     },
                     'blit_data' => $image,
                 }
@@ -1281,8 +1280,7 @@ sub rotate {
             );
 
             $F->blit_write($rot);
-$DIRTY = 1;
-            
+            $DIRTY = 1;
 
             $angle += 3;
             $angle = 0 if ($angle >= 360);
@@ -1304,7 +1302,7 @@ $DIRTY = 1;
                 {
                     'rotate' => {
                         'degrees' => $angle,
-                        'quality'   => ($p) ? 'high' : 'quick',
+                        'quality' => ($p) ? 'high' : 'quick',
                     },
                     'blit_data' => $image,
                     'perl_only' => $p
@@ -1318,12 +1316,12 @@ $DIRTY = 1;
             );
 
             $F->blit_write($rot);
-$DIRTY = 1;
+            $DIRTY = 1;
 
             $angle -= 3;
             $angle = 0 if ($angle <= -360);
             $count++;
-            
+
         } ## end while (time < $s || $count...)
         last if ($F->{'BITS'} == 16);
     } ## end foreach my $p (0 .. 1)
@@ -1334,10 +1332,11 @@ sub flipping {
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
 
     $image->{'y'} = $F->{'Y_CLIP'};
-    my $s = time + $factor * 2;
+    my $s    = time + $factor * 2;
     my $zoom = time + $factor;
     while (time < $s) {
-#        foreach my $dir (qw(normal vertical horizontal)) {
+
+        #        foreach my $dir (qw(normal vertical horizontal)) {
         foreach my $dir (qw(normal horizontal vertical both)) {
             my $rot = $F->blit_transform(
                 {
@@ -1349,13 +1348,12 @@ sub flipping {
             $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
             print_it($F, "Testing Image Flip $dir");
             $F->blit_write($rot);
-$DIRTY = 1;
-            
+            $DIRTY = 1;
 
             if (time < $zoom) {
                 sleep .3;
             } else {
-                sleep (1/30); # Some framebuffers can't keep up
+                sleep(1 / 30);    # Some framebuffers can't keep up
             }
         } ## end foreach my $dir (qw(normal horizontal vertical both))
     } ## end while (time < $s)
@@ -1374,12 +1372,12 @@ sub monochrome {
         $mono->{'x'} = abs(rand($XX - $mono->{'width'}));
         $mono->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $mono->{'height'}));
         $F->blit_write($mono);
-        
-    }
+
+    } ## end while (time < $s)
 } ## end sub monochrome
 
 sub animated {
-    $F->{'DIAGNOSTICS'} = 1;    
+    $F->{'DIAGNOSTICS'} = 1;
     print_it($F, 'Testing Animated Images.  Loading...', 'FFFF00FF');
     opendir(my $DIR, $images_path);
     chomp(my @list = readdir($DIR));
@@ -1389,9 +1387,9 @@ sub animated {
     foreach my $info (@list) {
         next unless ($info =~ /\.gif$/i);
         for my $count (0 .. 1) {
-            
+
             if ($count || $XX <= 320) {
-                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF', {'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255});
+                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF', { 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
                 print STDERR "\n";
                 $image = $F->load_image(
                     {
@@ -1402,7 +1400,7 @@ sub animated {
                     }
                 );
             } else {
-                print_it($F, "Loading Animated Image '$info' Native Size", 'FFFF00FF', {'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255});
+                print_it($F, "Loading Animated Image '$info' Native Size", 'FFFF00FF', { 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
                 print STDERR "\n";
                 $image = $F->load_image(
                     {
@@ -1411,20 +1409,20 @@ sub animated {
                     }
                 );
             } ## end else [ if ($count || $XX <= 320)]
-            
 
             foreach my $bench (0 .. 1) {
                 if ($count || $XX <= 320) {
-                    print_it($F, $bench ? "Benchmarking Animated Image of '$info' Fullscreen" : "Playing Animated Image of '$info' Fullscreen",$bench ? '0066FFFF' : 'FF00FFFF', $bench ? {'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255} : undef);
+                    print_it($F, $bench ? "Benchmarking Animated Image of '$info' Fullscreen" : "Playing Animated Image of '$info' Fullscreen", $bench ? '0066FFFF' : 'FF00FFFF', $bench ? { 'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255 } : undef);
                 } else {
-                    print_it($F, $bench ? "Benchmarking Animated Image of '$info' Native Size" : "Playing Animated Image of '$info' Native Size",$bench ? '0066FFFF' : 'FF00FFFF', $bench ? {'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255} : undef );
+                    print_it($F, $bench ? "Benchmarking Animated Image of '$info' Native Size" : "Playing Animated Image of '$info' Native Size", $bench ? '0066FFFF' : 'FF00FFFF', $bench ? { 'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255 } : undef);
                 }
                 if (defined($image)) {
                     $F->cls();
                     my $fps   = 0;
                     my $start = time;
                     my $s     = time + ($factor * 2);
-#                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
+
+                    #                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                             if (time > $s * 2) {
@@ -1434,8 +1432,8 @@ sub animated {
                             }
                             my $begin = time;
                             $F->blit_write($image->[$frame]);
-$DIRTY = 1;
-                            
+                            $DIRTY = 1;
+
                             my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * .01)) - (time - $begin);
                             if ($delay > 0 && !$bench) {
                                 sleep $delay;
@@ -1458,10 +1456,10 @@ $DIRTY = 1;
 } ## end sub animated
 
 sub mode_drawing {
-    my $mode = shift;
+    my $mode  = shift;
     my @modes = qw( NORMAL XOR OR AND MASK UNMASK ALPHA ADD SUBTRACT MULTIPLY DIVIDE );
     print_it($F, 'Testing ' . $modes[$mode] . ' Drawing Mode');
-    my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2;
     do {
         $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1474,14 +1472,14 @@ sub mode_drawing {
 
     $F->normal_mode();
     $F->blit_write($image);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep 2;
 
     $F->{'DRAW_MODE'} = $mode;
     $F->blit_write($image2);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep 2;
 
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
@@ -1495,34 +1493,34 @@ $DIRTY = 1;
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor;
-} ## end sub or_drawing
+} ## end sub mode_drawing
 
 sub alpha_drawing {
-    
+
     $F->attribute_reset();
     print_it($F, 'Testing Alpha Drawing Mode');
-    my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2;
     do {
         $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
     } until ($image2->{'image'} ne $image->{'image'});
-    my $size   = length($image2->{'image'}) / $F->{'BYTES'};
+    my $size = length($image2->{'image'}) / $F->{'BYTES'};
     $image2->{'image'} &= pack('C4', 255, 255, 255, 0) x $size;
     $image2->{'image'} |= pack('C4', 0, 0, 0, 128) x $size;
 
     $F->normal_mode();
     $F->blit_write($image);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep 2;
 
     $F->alpha_mode();
     $F->blit_write($image2);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep 2;
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => int(rand(256)) });
@@ -1533,18 +1531,18 @@ $DIRTY = 1;
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => int(rand(256)) });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor;
 } ## end sub alpha_drawing
 
 sub mask_drawing {
-    
+
     $F->attribute_reset();
     print_it($F, 'Testing MASK Drawing Mode');
 
     $F->set_b_color({ 'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 0 });
-    my $h      = int($YY - $F->{'Y_CLIP'});
+    my $h = int($YY - $F->{'Y_CLIP'});
     my $image1;
     my $image2 = $IMAGES[$BW];
     do {
@@ -1553,20 +1551,20 @@ sub mask_drawing {
     $F->normal_mode();
     $F->blit_write($image1);
     $F->mask_mode();
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep .3;
     $F->blit_write($image2);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor;
 } ## end sub mask_drawing
 
 sub unmask_drawing {
-    
+
     print_it($F, 'Testing UNMASK Drawing Mode');
 
-    my $h      = int($YY - $F->{'Y_CLIP'});
+    my $h = int($YY - $F->{'Y_CLIP'});
     my $image2;
     my $image1 = $IMAGES[$BW];
     do {
@@ -1575,12 +1573,12 @@ sub unmask_drawing {
     $F->normal_mode();
     $F->blit_write($image1);
     $F->unmask_mode();
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep .3;
     $F->blit_write($image2);
-$DIRTY = 1;
-    
+    $DIRTY = 1;
+
     sleep $factor;
 } ## end sub unmask_drawing
 
@@ -1588,16 +1586,18 @@ sub print_it {
     my $fb      = shift;
     my $message = shift;
     my $color   = shift || 'FFFF00FF';
-    my $bgcolor = shift || {'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 0};
+    my $bgcolor = shift || { 'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 0 };
     my $noclear = shift || 0;
 
     $fb->normal_mode();
-#    $fb->clip_reset();
+
+    #    $fb->clip_reset();
     $fb->set_b_color($bgcolor);
     $fb->cls() unless ($noclear);
-    system('clear') unless($noclear);
+    system('clear') unless ($noclear);
     unless ($XX <= 320) {
-#        $fb->or_mode();
+
+        #        $fb->or_mode();
 
         my $b = $fb->ttf_print(
             {
@@ -1612,20 +1612,20 @@ sub print_it {
                 'antialias'    => 0
             }
         );
-        $fb->clip_set({ 'x' => 0, 'y'=> 0, 'yy' => $b->{'pheight'} * .75, 'xx' => $XX});
+        $fb->clip_set({ 'x' => 0, 'y' => 0, 'yy' => $b->{'pheight'} * .75, 'xx' => $XX });
         $fb->cls();
         $fb->ttf_print($b);
         $fb->clip_set({ 'x' => 0, 'y' => $b->{'pheight'} * .75, 'xx' => $XX, 'yy' => $YY });
-#        $center_y = (($YY - $b->{'pheight'}) / 2) + $b->{'pheight'};
-#        $fb->normal_mode();
+
+        #        $center_y = (($YY - $b->{'pheight'}) / 2) + $b->{'pheight'};
+        #        $fb->normal_mode();
     } else {
         system('clear') unless ($noclear);
         print STDERR "$message\n";
     }
-$DIRTY = 1;
-    
-} ## end sub print_it
+    $DIRTY = 1;
 
+} ## end sub print_it
 
 __END__
 
@@ -1693,6 +1693,6 @@ Richard Kelsch <rich@rk-internet.com>
 
 =head1 COPYRIGHT
 
-Copyright 2003-2015 Richard Kelsch
+Copyright 2003-2016 Richard Kelsch
 
 This program must always be included as part of the Graphics::Framebuffer package.
